package com.sky.ioc.service.carbon.impl;

import com.alibaba.fastjson.JSONObject;
import com.sky.ioc.entity.Indeicator;
import com.sky.ioc.entity.Label;
import com.sky.ioc.entity.Cake;
import com.sky.ioc.entity.News;
import com.sky.ioc.entity.params.IocParam;
import com.sky.ioc.entity.params.IocTimeRange;
import com.sky.ioc.mapper.BusMapper;
import com.sky.ioc.mapper.PrintMapper;
import com.sky.ioc.service.carbon.CarbonService;
import com.sky.ioc.tool.DateUtil;
import com.sky.ioc.tool.GeneralMethod;
import com.sky.ioc.tool.ReturnMsg;
import io.swagger.models.auth.In;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.ThreadLocalRandom;

/**
 * TODO  双碳
 * @Description
 * @Author LunCe
 * @Date 2023/2/22 11:40
 **/

@Service
public class CarbonServiceImpl implements CarbonService {


    @Autowired
    BusMapper busMapper;

    @Autowired
    PrintMapper printMapper;

    /**
     * TODO  智能看板 --碳配额
     * @Description
     * @Return com.sky.ioc.tool.ReturnMsg
     * @Author LunCe
     * @date 2023/2/22 11:41
     */
    @Override
    public ReturnMsg getCarbonQuota() {
        String[] param = {"consumed","carbonQuota"};
        String[] labelKey = {"总部","规划院","郑分","广分","上分"};
        List<Label> labels = GeneralMethod.getInstance().dataGeneration(param, labelKey);
        return ReturnMsg.ok(labels);
    }

    @Override
    public ReturnMsg getPrintingCoreIndicators(IocParam iocParam) {
        Indeicator indeicator = new Indeicator();
        List<JSONObject> objects = indeicator.getList();
        float compare = (float) Math.random();
        DecimalFormat decimalFormat = new DecimalFormat("#.0");
        compare = Float.parseFloat(decimalFormat.format(compare));
        Double avgCost = printMapper.getAvgCost(iocParam);
        Double avgPaper = printMapper.getAvgPaper(iocParam);
        Double avgCarbon = printMapper.getAvgCarbon(iocParam);
        avgCost = Double.valueOf(decimalFormat.format(avgCost));
        avgPaper = Double.valueOf(decimalFormat.format(avgPaper));
        avgCarbon = Double.valueOf(decimalFormat.format(avgCarbon));
        Integer total = printMapper.getTotal(iocParam);
        total= total==null?0:total;

        objects.get(0).put("value",avgCost);
        objects.get(0).put("compare",compare);

        objects.get(1).put("value",avgPaper);
        objects.get(1).put("compare",compare);

        objects.get(2).put("value",avgCarbon);
        objects.get(2).put("compare",compare);

        objects.get(3).put("value",total);
        objects.get(3).put("compare",compare);
        indeicator.setWorthAttention("⽂印管理持续为您服务");
        indeicator.setList(objects);
        return ReturnMsg.ok(indeicator);
    }

    @Override
    public ReturnMsg getPrintingCostTrend(IocParam iocParam) {
        String[] param = {"cost"};
        //String[] labKey = {"1月","2月","3月","4月","5月","6月","7月","8月","9月","10月","11月","12月"};
        //List<Label> labels1 = GeneralMethod.getInstance().dataGeneration(param, labKey);
        String startStr = iocParam.getTimeRange().getStartDate();
        String endStr = iocParam.getTimeRange().getEndDate();
        List<String> list = DateUtil.getBetweenDays(startStr, endStr);
        String[] labKey = list.toArray(new String[0]);
        List<Label> labels1 = new ArrayList<>();
        DecimalFormat decimalFormat = new DecimalFormat("#.0");
        for (int i = 0; i < labKey.length; i++) {
            Label label = new Label();
            JSONObject jsonObject = new JSONObject();
            IocParam iocParam1 = new IocParam();
            iocParam1.setCompanyId(iocParam.getCompanyId());
            iocParam1.setDeptId(iocParam.getDeptId());
            IocTimeRange iocTimeRange = new IocTimeRange();
            iocTimeRange.setStartDate(labKey[i]+" 00:00:00");
            iocTimeRange.setEndDate(labKey[i]+" 23:59:00");
            iocParam1.setTimeRange(iocTimeRange);
            Double avgCost = printMapper.getAvgCost(iocParam1);
            avgCost =Double.valueOf(decimalFormat.format(avgCost));
            jsonObject.put(param[0],avgCost);
            label.setJsonObject(jsonObject);
            label.setLabel(labKey[i]);
            labels1.add(label);
        }
        return ReturnMsg.ok(labels1);
    }

    @Override
    public ReturnMsg getConferenceRoomInfo(IocParam iocParam) {
        String[] param = {"print","inkCartridge"};
        String startStr = iocParam.getTimeRange().getStartDate();
        String endStr = iocParam.getTimeRange().getEndDate();
        List<String> list = DateUtil.getBetweenDays(startStr, endStr);
        String[] labKey = list.toArray(new String[0]);
        List<Label> labels1 = new ArrayList<>();
        DecimalFormat decimalFormat = new DecimalFormat("#.0");
        for (int i = 0; i < labKey.length; i++) {
            Label label = new Label();
            JSONObject jsonObject = new JSONObject();
            IocParam iocParam1 = new IocParam();
            IocTimeRange iocTimeRange = new IocTimeRange();
            iocTimeRange.setStartDate(labKey[i]+" 00:00:00");
            iocTimeRange.setEndDate(labKey[i]+" 23:59:00");
            iocParam1.setTimeRange(iocTimeRange);
            Integer totalPaper = printMapper.getTotalPaper(iocParam1);
            Double totalInkbox = printMapper.getTotalInkbox(iocParam1);
            totalInkbox = Double.valueOf(decimalFormat.format(totalInkbox));
            jsonObject.put(param[0],totalPaper);
            jsonObject.put(param[1],totalInkbox);
            label.setJsonObject(jsonObject);
            label.setLabel(labKey[i]);
            labels1.add(label);
        }
        return ReturnMsg.ok(labels1);
    }

    @Override
    public ReturnMsg getBusCoreIndicators(IocParam iocParam) {
        Indeicator indeicator = new Indeicator();
        List<JSONObject> objects = indeicator.getList();
        DecimalFormat decimalFormat = new DecimalFormat("#.0");
        Double avgCost = busMapper.getAvgCostByCompanyIdAndDeptId(iocParam);
        Double totalHours = busMapper.getTotalHoursByCompanyIdAndDeptId(iocParam);
        Integer totalBus = busMapper.getTotalBusByCompanyIdAndDeptId(iocParam);
        Integer total = busMapper.getTotalByCompanyIdAndDeptId(iocParam);
        BigDecimal bigDecimal1 = new BigDecimal(avgCost);
        BigDecimal avgCostDec = bigDecimal1.divide(new BigDecimal(365), 2, RoundingMode.HALF_UP);
        avgCost = avgCostDec.doubleValue();
     //  avgCost = Double.valueOf(decimalFormat.format(avgCost));
        Double totalCarbon = busMapper.getTotalCarbonByCompanyIdAndDeptId(iocParam);
        double avgHours = 0d;
        double avgCarbon = 0d;
        double avgTimes = 0d;
        if(total>0){
            if(totalBus>0){
                BigDecimal bigDecimal = new BigDecimal(totalBus);
                BigDecimal avgTimesDec = bigDecimal.divide(new BigDecimal(total), 2, RoundingMode.HALF_UP);
                avgTimes = avgTimesDec.doubleValue();
            }
            if(totalHours>0){
                BigDecimal bigDecimal = new BigDecimal(totalHours);
                BigDecimal avgHoursDec = bigDecimal.divide(new BigDecimal(total), 2, RoundingMode.HALF_UP);
                avgHours = avgHoursDec.doubleValue();
            }
            if(totalCarbon>0){
                BigDecimal bigDecimal = new BigDecimal(totalCarbon);
                BigDecimal avgCarbonDec = bigDecimal.divide(new BigDecimal(total), 2, RoundingMode.HALF_UP);
                avgCarbon = avgCarbonDec.doubleValue();
            }
        }
        ThreadLocalRandom random = ThreadLocalRandom.current();
        double compare = random.nextDouble(-1, 1);
        compare = Double.parseDouble(decimalFormat.format(compare));
        objects.get(0).put("value",avgCost);
        objects.get(0).put("compare",compare);

        objects.get(1).put("value",avgTimes);
        objects.get(1).put("compare",compare);

        objects.get(2).put("value",avgCarbon);
        objects.get(2).put("compare",compare);

        objects.get(3).put("value",avgHours);
        objects.get(3).put("compare",compare);
        indeicator.setWorthAttention("公车管理持续为您服务");
        indeicator.setList(objects);
        return ReturnMsg.ok(indeicator);
    }

    @Override
    public ReturnMsg getBusInfo(IocParam iocParam) {
        String[] param = {"averageDuration","numberTrips"};
        String startStr = iocParam.getTimeRange().getStartDate();
        String endStr = iocParam.getTimeRange().getEndDate();
        List<String> list = DateUtil.getBetweenDays(startStr, endStr);
        String[] labKey = list.toArray(new String[0]);
        List<Label> labels1 = new ArrayList<>();
        DecimalFormat decimalFormat = new DecimalFormat("#.0");
        for (int i = 0; i < labKey.length; i++) {
            Label label = new Label();
            JSONObject jsonObject = new JSONObject();
            IocParam iocParam1 = new IocParam();
            IocTimeRange iocTimeRange = new IocTimeRange();
            iocTimeRange.setStartDate(labKey[i]+" 00:00:00");
            iocTimeRange.setEndDate(labKey[i]+" 23:59:00");
            iocParam1.setTimeRange(iocTimeRange);
            Double totalHours = busMapper.getTotalHoursByCompanyIdAndDeptId(iocParam1);
            Integer total = busMapper.getTotalByCompanyIdAndDeptId(iocParam1);
            double avgHours = 0d;
            if(total>0){
                if(totalHours>0){
                    BigDecimal bigDecimal = new BigDecimal(totalHours);
                    BigDecimal avgHoursDec = bigDecimal.divide(new BigDecimal(total), 2, RoundingMode.HALF_UP);
                    avgHours = avgHoursDec.doubleValue();
                }
            }
            jsonObject.put(param[0],avgHours);
            jsonObject.put(param[1],total);

            label.setJsonObject(jsonObject);
            label.setLabel(labKey[i]);
            labels1.add(label);
        }
        return ReturnMsg.ok(labels1);
    }

    @Override
    public ReturnMsg getBusCostTrend(IocParam iocParam) {
        String[] param = {"cost"};
        String startStr = iocParam.getTimeRange().getStartDate();
        String endStr = iocParam.getTimeRange().getEndDate();
        List<String> list = DateUtil.getBetweenDays(startStr, endStr);
        String[] labKey = list.toArray(new String[0]);
        List<Label> labels1 = new ArrayList<>();
        DecimalFormat decimalFormat = new DecimalFormat("#.0");
        for (int i = 0; i < labKey.length; i++) {
            Label label = new Label();
            JSONObject jsonObject = new JSONObject();
            IocParam iocParam1 = new IocParam();
            IocTimeRange iocTimeRange = new IocTimeRange();
            iocTimeRange.setStartDate(labKey[i]+" 00:00:00");
            iocTimeRange.setEndDate(labKey[i]+" 23:59:00");
            iocParam1.setTimeRange(iocTimeRange);
            Double avgCost = busMapper.getAvgCostByCompanyIdAndDeptId(iocParam1);
            avgCost = Double.valueOf(decimalFormat.format(avgCost));
            jsonObject.put(param[0],avgCost);
            label.setJsonObject(jsonObject);
            label.setLabel(labKey[i]);
            labels1.add(label);
        }
        return ReturnMsg.ok(labels1);
    }

    @Override
    public ReturnMsg getFloorCoreIndicators(IocParam iocParam) {
        Indeicator indeicator = new Indeicator();
        List<JSONObject> objects = indeicator.getList();
        ThreadLocalRandom random = ThreadLocalRandom.current();
        int stockCarbon = random.nextInt(10, 100);
        int totalCarbon = random.nextInt(100,8000);
        int areaCarbon = random.nextInt(10,800);
        int personCarbon = random.nextInt(10,80);
        while (areaCarbon>totalCarbon){
            areaCarbon = random.nextInt(10,800);
        }
        while (personCarbon>totalCarbon){
            personCarbon = random.nextInt(10,80);
        }
        int derCarbon = random.nextInt(10,80);
        float compare = (float) Math.random();
        DecimalFormat decimalFormat = new DecimalFormat("#.0");
        compare = Float.parseFloat(decimalFormat.format(compare));

        objects.get(0).put("value",stockCarbon);

        objects.get(1).put("value",totalCarbon);
        objects.get(1).put("compare",compare);

        objects.get(2).put("value",areaCarbon);
        objects.get(2).put("compare",compare);

        objects.get(3).put("value",personCarbon);
        objects.get(3).put("compare",compare);
        objects.add(new JSONObject());
        objects.get(4).put("value",derCarbon);
        objects.get(4).put("compare",compare);

        indeicator.setWorthAttention("节能减排绿色出行");
        indeicator.setList(objects);
        return ReturnMsg.ok(indeicator);
    }

    @Override
    public ReturnMsg getCarbonInfo(IocParam iocParam) {
        String[] param = {"zhongxun","guihuayuanBJ","zhengfen","guangfen","shangfen","chengfen"};
        List<String> lists = DateUtil.getBetweenDays("2023/03/01", "2023/03/31");
        String[] labKey = lists.toArray(new String[0]);
        List<Label> labels1 = GeneralMethod.getInstance().dataGeneration(param, labKey);
        return ReturnMsg.ok(labels1);
    }

    @Override
    public ReturnMsg getCarbonQuotaComposition(IocParam iocParam) {
        String[] param = {"stock","consume"};
        String[] labKey = {"中旬","规划院","成分","上分","广分","郑分"};
        List<Label> labels1 = GeneralMethod.getInstance().dataGeneration(param, labKey);
        return ReturnMsg.ok(labels1);
    }

    @Override
    public ReturnMsg getCarbonNews(IocParam iocParam) {
        List<News> newsList = new ArrayList<>();
        newsList.add(new News());
        newsList.add(new News());
        newsList.add(new News());
        return ReturnMsg.ok(newsList);
    }

    @Override
    public ReturnMsg getCarbonProportion(IocParam iocParam) {
        List<Cake> list = new ArrayList<>();
        list.add(new Cake("汽油"));
        list.add(new Cake("柴油"));
        list.add(new Cake("电力"));
        list.add(new Cake("热力"));
        list.add(new Cake("天然气"));
        list.add(new Cake("其他"));
        return ReturnMsg.ok(list);
    }

    @Override
    public ReturnMsg getVehicleCoreIndicators(IocParam iocParam) {
        Indeicator indeicator = new Indeicator();
        List<JSONObject> objects = indeicator.getList();
        ThreadLocalRandom random = ThreadLocalRandom.current();
        int totalDistance = random.nextInt(50, 200);
        int avgDistance = random.nextInt(5,100);
        int avgHours = random.nextInt(1,10);
        int avgCarbon = random.nextInt(50,500);
        while (avgDistance>totalDistance){
            avgDistance = random.nextInt(5,100);
        }
        float compare = (float) Math.random();
        DecimalFormat decimalFormat = new DecimalFormat("#.0");
        compare = Float.parseFloat(decimalFormat.format(compare));

        objects.get(0).put("value",totalDistance);
        objects.get(0).put("compare",compare);

        objects.get(1).put("value",avgDistance);
        objects.get(1).put("compare",compare);

        objects.get(2).put("value",avgHours);
        objects.get(2).put("compare",compare);

        objects.get(3).put("value",avgCarbon);
        objects.get(3).put("compare",compare);
        indeicator.setWorthAttention("节能减排绿色出行");
        indeicator.setList(objects);
        return ReturnMsg.ok(indeicator);
    }

    @Override
    public ReturnMsg getVehicleInfo(IocParam iocParam) {
        String[] param = {"zhongxun","guihuayuanBJ","zhengfen","guangfen","shangfen","chengfen"};
        List<String> lists = DateUtil.getBetweenDays("2023/03/01", "2023/03/31");
        String[] labKey = lists.toArray(new String[0]);
        List<Label> labels1 = GeneralMethod.getInstance().dataGeneration(param, labKey);
        return ReturnMsg.ok(labels1);
    }

    @Override
    public ReturnMsg getVehicleInfoOrder(IocParam iocParam) {
        String[] param = {"Vehicle"};
        String[] labKey = {"中旬","规划院","成分","上分","广分","郑分"};
        List<Label> labels1 = GeneralMethod.getInstance().dataGeneration(param, labKey);
        return ReturnMsg.ok(labels1);
    }

    @Override
    public ReturnMsg getPrintCoreIndicators(IocParam iocParam) {
        Indeicator indeicator = new Indeicator();
        List<JSONObject> objects = indeicator.getList();
        ThreadLocalRandom random = ThreadLocalRandom.current();
        int totalPrint = random.nextInt(100, 1000);
        int avgPrint = random.nextInt(50,500);
        int avgPaper = random.nextInt(1,200);
        int avgCartridge = random.nextInt(10,100);
        while (avgCartridge>avgPaper){
            avgCartridge = random.nextInt(10,100);
        }
        while (avgPrint>totalPrint){
            avgPrint = random.nextInt(50,500);
        }
        float compare = (float) Math.random();
        DecimalFormat decimalFormat = new DecimalFormat("#.0");
        compare = Float.parseFloat(decimalFormat.format(compare));
        objects.get(0).put("value",totalPrint);
        objects.get(0).put("compare",compare);

        objects.get(1).put("value",avgPrint);
        objects.get(1).put("compare",compare);

        objects.get(2).put("value",avgPaper);
        objects.get(2).put("compare",compare);

        objects.get(3).put("value",avgCartridge);
        objects.get(3).put("compare",compare);
        indeicator.setWorthAttention("⽂印管理持续为您服务");
        indeicator.setList(objects);
        return ReturnMsg.ok(indeicator);
    }

    @Override
    public ReturnMsg getPrintInfoOrder(IocParam iocParam) {
        String[] param = {"Print"};
        String[] labKey = {"中旬","规划院","成分","上分","广分","郑分"};
        List<Label> labels1 = GeneralMethod.getInstance().dataGeneration(param, labKey);
        return ReturnMsg.ok(labels1);
    }

    @Override
    public ReturnMsg getPrintInfo(IocParam iocParam) {
        String[] param = {"zhongxun","guihuayuanBJ","zhengfen","guangfen","shangfen","chengfen"};
        List<String> lists = DateUtil.getBetweenDays("2023/03/01", "2023/03/31");
        String[] labKey = lists.toArray(new String[0]);
        List<Label> labels1 = GeneralMethod.getInstance().dataGeneration(param, labKey);
        return ReturnMsg.ok(labels1);
    }

    @Override
    public ReturnMsg getPhotovoltaicInfoOrder(IocParam iocParam) {
        String[] param = {"Photovoltaic"};
        String[] labKey = {"中旬","规划院","成分","上分","广分","郑分"};
        List<Label> labels1 = GeneralMethod.getInstance().dataGeneration(param, labKey);
        return ReturnMsg.ok(labels1);
    }

    @Override
    public ReturnMsg getPhotovoltaicInfo(IocParam iocParam) {
        String[] param = {"zhongxun","guihuayuanBJ","zhengfen","guangfen","shangfen","chengfen"};
        List<String> lists = DateUtil.getBetweenDays("2023/03/01", "2023/03/31");
        String[] labKey = lists.toArray(new String[0]);
        List<Label> labels1 = GeneralMethod.getInstance().dataGeneration(param, labKey);
        return ReturnMsg.ok(labels1);
    }

    @Override
    public ReturnMsg getPhotovoltaicCoreIndicators(IocParam iocParam) {
        Indeicator indeicator = new Indeicator();
        List<JSONObject> objects = indeicator.getList();
        ThreadLocalRandom random = ThreadLocalRandom.current();
        int reduPhotovoltaic = random.nextInt(1000, 10000);
        int elecPhotovoltaic = random.nextInt(500,5000);
        int savePhotovoltaic = random.nextInt(500,5000);
        int subPhotovoltaic = random.nextInt(100,1000);

        float compare = (float) Math.random();
        DecimalFormat decimalFormat = new DecimalFormat("#.0");
        compare = Float.parseFloat(decimalFormat.format(compare));
        objects.get(0).put("value",reduPhotovoltaic);
        objects.get(0).put("compare",compare);

        objects.get(1).put("value",elecPhotovoltaic);
        objects.get(1).put("compare",compare);

        objects.get(2).put("value",savePhotovoltaic);
        objects.get(2).put("compare",compare);

        objects.get(3).put("value",subPhotovoltaic);
        objects.get(3).put("compare",compare);
        indeicator.setWorthAttention("光伏发电持续为您服务");
        indeicator.setList(objects);
        return ReturnMsg.ok(indeicator);
    }

    @Override
    public ReturnMsg getPhotovoltaicPower() {
        String[] param = {"realTime"};
        String[] labelKey = {"8:00-10:00","10:00-12:00","12:00-14:00","14:00-16:00","16:00-18:00"};
        List<Label> labels = GeneralMethod.getInstance().dataGeneration(param, labelKey);
        return ReturnMsg.ok(labels);
    }


    @Override
    public ReturnMsg getAnalyseCoreIndicators(IocParam iocParam) {
        Indeicator indeicator = new Indeicator();
        List<JSONObject> objects = indeicator.getList();
        ThreadLocalRandom random = ThreadLocalRandom.current();
        DecimalFormat decimalFormat = new DecimalFormat("#.0");
        int totalKwh = random.nextInt(10, 100);
        int totalM = random.nextInt(10, 100);
        int costCount = random.nextInt(1000, 5000);
        int costAvg = random.nextInt(300, 1000);
        while (costAvg>costCount){
            costAvg = random.nextInt(300, 1000);
        }
        float compare = (float) Math.random();
        compare = Float.parseFloat(decimalFormat.format(compare));
        objects.get(0).put("value",totalKwh);
        objects.get(0).put("compare",compare);

        objects.get(1).put("value",totalM);
        objects.get(1).put("compare",compare);

        objects.get(2).put("value",costCount);
        objects.get(2).put("compare",compare);

        objects.get(3).put("value",costAvg);
        objects.get(3).put("compare",compare);
        indeicator.setWorthAttention("⼈均成本过⾼，建议合理搭配智慧场景调整能源使⽤策略");
        indeicator.setList(objects);
        return ReturnMsg.ok(indeicator);
    }

    @Override
    public ReturnMsg getAnalyseWaterCoreIndicators(IocParam iocParam) {
        Indeicator indeicator = new Indeicator();
        List<JSONObject> objects = indeicator.getList();
        objects.get(0).put("value",98);
        objects.get(0).put("compare",0.4);

        objects.get(1).put("value",50);
        objects.get(1).put("compare",0.4);

        objects.get(2).put("value",100);
        objects.get(2).put("compare",0.4);

        objects.get(3).put("value",1000);
        objects.get(3).put("compare",0.4);
        indeicator.setWorthAttention("⼈均成本过⾼，建议合理搭配智慧场景调整能源使⽤策略");
        indeicator.setList(objects);
        return ReturnMsg.ok(indeicator);
    }

    @Override
    public ReturnMsg getAnalysePowerCoreIndicators(IocParam iocParam) {
        Indeicator indeicator = new Indeicator();
        List<JSONObject> objects = indeicator.getList();
        objects.get(0).put("value",98);
        objects.get(0).put("compare",0.4);

        objects.get(1).put("value",30);
        objects.get(1).put("compare",0.4);

        objects.get(2).put("value",100);
        objects.get(2).put("compare",0.4);

        objects.get(3).put("value",1000);
        objects.get(3).put("compare",0.4);
        indeicator.setWorthAttention("⼈均成本过⾼，建议合理搭配智慧场景调整能源使⽤策略");
        indeicator.setList(objects);
        return ReturnMsg.ok(indeicator);
    }

    @Override
    public ReturnMsg getAnalyseHotCoreIndicators(IocParam iocParam) {
        Indeicator indeicator = new Indeicator();
        List<JSONObject> objects = indeicator.getList();
        objects.get(0).put("value",98);
        objects.get(0).put("compare",0.4);

        objects.get(1).put("value",50);
        objects.get(1).put("compare",0.4);

        objects.get(2).put("value",100);
        objects.get(2).put("compare",0.4);

        objects.get(3).put("value",1000);
        objects.get(3).put("compare",0.4);
        indeicator.setWorthAttention("⼈均成本过⾼，建议合理搭配智慧场景调整能源使⽤策略");
        indeicator.setList(objects);
        return ReturnMsg.ok(indeicator);
    }

    @Override
    public ReturnMsg getAnalyseColdCoreIndicators(IocParam iocParam) {
        Indeicator indeicator = new Indeicator();
        List<JSONObject> objects = indeicator.getList();
        objects.get(0).put("value",98);
        objects.get(0).put("compare",0.4);

        objects.get(1).put("value",50);
        objects.get(1).put("compare",0.4);

        objects.get(2).put("value",100);
        objects.get(2).put("compare",0.4);

        objects.get(3).put("value",1000);
        objects.get(3).put("compare",0.4);
        indeicator.setWorthAttention("⼈均成本过⾼，建议合理搭配智慧场景调整能源使⽤策略");
        indeicator.setList(objects);
        return ReturnMsg.ok(indeicator);
    }

    @Override
    public ReturnMsg getAnalyseCpvCoreIndicators(IocParam iocParam) {
        Indeicator indeicator = new Indeicator();
        List<JSONObject> objects = indeicator.getList();
        objects.get(0).put("value",98);
        objects.get(0).put("compare",0.4);

        objects.get(1).put("value",50);
        objects.get(1).put("compare",0.4);

        objects.get(2).put("value",100);
        objects.get(2).put("compare",0.4);

        objects.get(3).put("value",1000);
        objects.get(3).put("compare",0.4);
        indeicator.setWorthAttention("⼈均成本过⾼，建议合理搭配智慧场景调整能源使⽤策略");
        indeicator.setList(objects);
        return ReturnMsg.ok(indeicator);
    }

    @Override
    public ReturnMsg getPhotovoltaicProfit() {
        List<Cake> list = new ArrayList<>();
        list.add(new Cake("amountSubsidy"));
        list.add(new Cake("saving"));
        return ReturnMsg.ok(list);
    }

    @Override
    public ReturnMsg getEnergyTrendsAnalyseWater(IocParam iocParam) {
        String[] param = {"tapWater","recycledWater"};
        List<String> lists = DateUtil.getBetweenDays("2023/03/01", "2023/03/31");
        String[] labKey = lists.toArray(new String[0]);
        List<Label> labels1 = GeneralMethod.getInstance().dataGeneration(param, labKey);
        return ReturnMsg.ok(labels1);
    }

    @Override
    public ReturnMsg getEnergyTrendsAnalysePower(IocParam iocParam) {
        String[] param = {"tip","seal","flat","valley"};
        List<String> lists = DateUtil.getBetweenDays("2023/03/01", "2023/03/31");
        String[] labKey = lists.toArray(new String[0]);
        List<Label> labels1 = GeneralMethod.getInstance().dataGeneration(param, labKey);
        return ReturnMsg.ok(labels1);
    }

    @Override
    public ReturnMsg getEnergyTrendsAnalyseHot(IocParam iocParam) {
        String[] param = {"heatConsumption"};
        List<String> lists = DateUtil.getBetweenDays("2023/03/01", "2023/03/31");
        String[] labKey = lists.toArray(new String[0]);
        List<Label> labels1 = GeneralMethod.getInstance().dataGeneration(param, labKey);
        return ReturnMsg.ok(labels1);
    }

    @Override
    public ReturnMsg getEnergyTrendsAnalyseCold(IocParam iocParam) {
        String[] param = {"refrigerationCapacity","energyConsumption"};
        List<String> lists = DateUtil.getBetweenDays("2023/03/01", "2023/03/31");
        String[] labKey = lists.toArray(new String[0]);
        List<Label> labels1 = GeneralMethod.getInstance().dataGeneration(param, labKey);
        return ReturnMsg.ok(labels1);
    }

    @Override
    public ReturnMsg getEnergyTrendsAnalyseCpv(IocParam iocParam) {
        String[] param = {"powerGeneration","outputPower"};
        List<String> lists = DateUtil.getBetweenDays("2023/03/01", "2023/03/31");
        String[] labKey = lists.toArray(new String[0]);
        List<Label> labels1 = GeneralMethod.getInstance().dataGeneration(param, labKey);
        return ReturnMsg.ok(labels1);
    }

    @Override
    public ReturnMsg getEnergyTrendsTotal(IocParam iocParam) {
        String[] param = {"water","cpv","cold","hot","power"};
        List<String> lists = DateUtil.getBetweenDays("2023/03/01", "2023/03/31");
        String[] labKey = lists.toArray(new String[0]);
        List<Label> labels1 = GeneralMethod.getInstance().dataGeneration(param, labKey);
        return ReturnMsg.ok(labels1);
    }

    @Override
    public ReturnMsg getEnergyTrendsAnalyseCpvInfo(IocParam iocParam) {
        String[] param = {"governmentSubsidies","save"};
        List<String> lists = DateUtil.getBetweenDays("2023/03/01", "2023/03/31");
        String[] labKey = lists.toArray(new String[0]);
        List<Label> labels1 = GeneralMethod.getInstance().dataGeneration(param, labKey);
        return ReturnMsg.ok(labels1);
    }

    @Override
    public ReturnMsg getEnergyAnalysisWater(IocParam iocParam) {
        List<Cake> list = new ArrayList<>();
        list.add(new Cake("office"));
        list.add(new Cake("computerRoom"));
        list.add(new Cake("restaurant"));
        list.add(new Cake("parkingLot"));
        list.add(new Cake("qita"));
        return ReturnMsg.ok(list);
    }

    @Override
    public ReturnMsg getEnergyAnalysisTotal(IocParam iocParam) {
        List<Cake> list = new ArrayList<>();
        list.add(new Cake("光伏"));
        list.add(new Cake("用热"));
        list.add(new Cake("用冷"));
        list.add(new Cake("用电"));
        list.add(new Cake("用水"));
        return ReturnMsg.ok(list);
    }

    @Override
    public ReturnMsg getEnergyAnalysisPower(IocParam iocParam) {
        List<Cake> list = new ArrayList<>();
        list.add(new Cake("computerRoom"));
        list.add(new Cake("socket"));
        list.add(new Cake("lighting"));
        list.add(new Cake("airConditioner"));
        list.add(new Cake("qita"));
        return ReturnMsg.ok(list);
    }

    @Override
    public ReturnMsg getEnergyAnalysisHot(IocParam iocParam) {
        List<Cake> list = new ArrayList<>();
        System.out.println(list);
        list.add(new Cake("computerRoom"));
        list.add(new Cake("parking"));
        list.add(new Cake("restaurant"));
        list.add(new Cake("office"));
        list.add(new Cake("qita"));
        return ReturnMsg.ok(list);
    }

    @Override
    public ReturnMsg getEnergyAnalysisClod(IocParam iocParam) {
        List<Cake> list = new ArrayList<>();
        System.out.println(list);
        list.add(new Cake("function"));
        list.add(new Cake("whole"));
        list.add(new Cake("clodTotal"));
        list.add(new Cake("perCapitaCost"));
        list.add(new Cake("inletWaterTemperature"));
        list.add(new Cake("outletWaterTemperature"));
        return ReturnMsg.ok(list);
    }

    @Override
    public ReturnMsg getEnergyAnalysisCpv(IocParam iocParam) {
        List<Cake> list = new ArrayList<>();
        System.out.println(list);
        list.add(new Cake("function"));
        list.add(new Cake("whole"));
        list.add(new Cake("electricTotal"));
        list.add(new Cake("electricDate"));
        list.add(new Cake("profitTotal"));
        return ReturnMsg.ok(list);
    }

    @Override
    public ReturnMsg getEnergyAnalysisTotalInfo(IocParam iocParam) {
        List<Cake> list = new ArrayList<>();
        System.out.println(list);
        list.add(new Cake("monthlyEnergySaving"));
        list.add(new Cake("annualEnergySaving"));
        return ReturnMsg.ok(list);
    }

    @Override
    public ReturnMsg getEnergyAnalysisWaterInfo(IocParam iocParam) {
        List<Cake> list = new ArrayList<>();
        System.out.println(list);
        list.add(new Cake("waterConsumptionTotal"));
        list.add(new Cake("perCapitaCost"));
        return ReturnMsg.ok(list);
    }

    @Override
    public ReturnMsg getEnergyAnalysisPowerInfo(IocParam iocParam) {
        List<Cake> list = new ArrayList<>();
        System.out.println(list);
        list.add(new Cake("powerConsumptionTotal"));
        list.add(new Cake("energyConservation"));
        return ReturnMsg.ok(list);
    }

    @Override
    public ReturnMsg getEnergyAnalysisHotInfo(IocParam iocParam) {
        List<Cake> list = new ArrayList<>();
        System.out.println(list);
        list.add(new Cake("heatConsumptionTotal"));
        list.add(new Cake("perCapitaCost"));
        return ReturnMsg.ok(list);
    }

}
